@@ -1,9 +1,10 @@
 #!/usr/bin/env bash
 # lesspipe.sh, a preprocessor for less
-lesspipe_version=2.13
+lesspipe_version=2.20
 # Author: Wolfgang Friebel (wp.friebel AT gmail.com)
 
 has_cmd () {
+	[[ -n "$2" && "$2" > $($1 --version 2>/dev/null) ]] && return 1
 	command -v "$1" > /dev/null
 }
 
@@ -11,7 +12,7 @@ fileext () {
 	fn=${1##*/}
 	case "$fn" in
 		.*.*) extension=${fn##*.} ;;
-		.*) extension= ;;
+		.*) extension=${fn#.} ;;
 		*.*) extension=${fn##*.} ;;
 	esac
 	echo "$extension"
@@ -78,19 +79,14 @@ filetype () {
 			[[ $fcat == text ]] && ftype="$fext" ;;
 		tsx)
 			[[ $fcat == text ]] && ftype=typescript-jsx ;;
-		appimage)
-			[[ $fcat == application && -x "$1" ]] && ftype="$fext" ;;
+		appimage|AppImage)
+			[[ $fcat == application && -x "$1" ]] && ftype=appimage ;;
 		snap)
 			[[ $fcat == application ]] && ftype="$fext" ;;
 	esac
 	### get file type from 'file' command for an unspecific result
-	if [[ "$fcat" == message && $ftype == plain ]]; then
-		ftype=msg
-	fi
-	if [[ "$fcat" == message && $ftype == rfc822 ]]; then
-		fcat=text
-		ftype=email
-	fi
+	[[ "$fcat" == message && $ftype == plain ]] && ftype=msg
+	[[ "$fcat" == message && $ftype == rfc822 ]] && fcat=text && ftype=email
 	if [[ "$fcat" == application && "$ftype" == octet-stream || "$fcat" == text && $ftype == plain ]]; then
 		ft=$(file -L -s -b "$1" 2> /dev/null)
 		# first check if the file command yields something
@@ -184,9 +180,17 @@ istemp () {
 		shift
 		t=$(nexttmp)
 		cat > "$t"
-		$prog "$t" "$@"
+		if [[ $prog == "ccze -A" ]]; then
+			$prog < "$t" "$@"
+		else
+			$prog "$t" "$@"
+		fi
 	else
-		$prog "$@"
+		if [[ $prog == "ccze -A" ]]; then
+			$prog < "$@"
+		else
+			$prog "$@"
+		fi
 	fi
 }
 
@@ -206,30 +210,22 @@ show () {
 	file1="${1%%"$sep"*}"
 	rest1="${1#"$file1"}"
 	while [[ "$rest1" == "$sep$sep"* ]]; do
-		if [[ "$rest1" == "$sep$sep" ]]; then
-			break
-		else
-			rest1="${rest1#"$sep$sep"}"
-			file1="${rest1%%"$sep"*}"
-			rest1="${rest1#"$file1"}"
-			file1="${1%"$rest1"}"
-		fi
+		[[ "$rest1" == "$sep$sep" ]] && break
+		rest1="${rest1#"$sep$sep"}"
+		file1="${rest1%%"$sep"*}"
+		rest1="${rest1#"$file1"}"
+		file1="${1%"$rest1"}"
 	done
-	if [[ ! -e "$file1" && "$file1" != '-' ]]; then
-		exit 1
-	fi
+	[[ ! -e "$file1" && "$file1" != '-' ]] && exit 1
 	rest11="${rest1#"$sep"}"
 	file2="${rest11%%"$sep"*}"
 	rest2="${rest11#"$file2"}"
 	while [[ "$rest2" == "$sep$sep"* ]]; do
-		if [[ "$rest2" == "$sep$sep" ]]; then
-			break
-		else
-			rest2="${rest2#"$sep$sep"}"
-			file2="${rest2%%"$sep"*}"
-			rest2="${rest2#"$file2"}"
-			file2="${rest11%"$rest2"}"
-		fi
+		[[ "$rest2" == "$sep$sep" ]] && break
+		rest2="${rest2#"$sep$sep"}"
+		file2="${rest2%%"$sep"*}"
+		rest2="${rest2#"$file2"}"
+		file2="${rest11%"$rest2"}"
 	done
 	rest2="${rest11#"$file2"}"
 	rest11="$rest1"
@@ -296,9 +292,7 @@ get_unpack_cmd () {
 	fcat="${1##*:}"
 	x="${1%%:*}"
 	cmd=()
-	if [[ "$3" == $sep$sep ]]; then
-		return
-	fi
+	[[ "$3" == $sep$sep ]] && return
 	declare t
 	# uncompress / transform
 	case $x in
@@ -307,30 +301,33 @@ get_unpack_cmd () {
 			[[ $2 == - ]] || fileext="$2"
 			fileext=${fileext%%.gz}; fileext=${fileext%%.bz2}
 			[[ $x == compress ]] && x=gzip
-			has_cmd "$x" && cmd=("$x" -cd "$2") && return ;;
+			has_cmd "$x" && cmd=("$x" -cd "$2") ;;
 		zstd)
-			has_cmd zstd && cmd=(zstd -cdqM1073741824 "$2") && return ;;
+			has_cmd zstd && cmd=(zstd -cdqM1073741824 "$2") ;;
 		lz4)
-			has_cmd lz4 && cmd=(lz4 -cdq "$2") && return ;;
+			has_cmd lz4 && cmd=(lz4 -cdq "$2") ;;
+		# xls(x) output looks better if transformed to csv and then displayed
 		xlsx)
-			has_cmd in2csv && cmd=(in2csv -f xlsx "$2") && return
-			has_cmd excel2csv && cmd=(istemp excel2csv "$2") && return ;;
+			{ has_cmd xlsx2csv 0.8.3 && cmd=(xlsx2csv "$2"); } ||
+			{ has_cmd in2csv && cmd=(in2csv -f xlsx "$2"); } ||
+			{ has_cmd excel2csv && cmd=(istemp excel2csv "$2"); } ;;
 		ms-excel)
-			has_cmd in2csv && cmd=(in2csv -f xls "$2") && return
-			has_cmd xls2csv && cmd=(istemp xls2csv "$2") && return ;;
+			{ has_cmd in2csv && cmd=(in2csv -f xls "$2"); } ||
+			{ has_cmd xls2csv && cmd=(istemp xls2csv "$2"); } ;;
 	esac
+	[[ ${cmd[*]} == '' ]] || return
 	# convert into utf8
 
-	if [[ -n $lclocale && $fchar != binary && $fchar != *ascii && $fchar != "$lclocale" && $fchar != unknown* ]]; then
+	if [[ -n $charmap && $fchar != binary && $fchar != *ascii && $fchar != "$charmap" && $fchar != unknown* ]]; then
 		qm="\033[7m?\033[m" # inverted question mark
 		rep=(-c)
 		trans=()
-		echo ""|iconv --byte-subst - 2>/dev/null && rep=(--unicode-subst="$qm" --byte-subst="$qm" --widechar-subst="$qm") # MacOS
-		echo ""|iconv -f "$fchar" -t "$locale//TRANSLIT" - 2>/dev/null && trans=(-t "$locale//TRANSLIT")
+		iconv --byte-subst - </dev/null 2>/dev/null && rep=(--unicode-subst="$qm" --byte-subst="$qm" --widechar-subst="$qm") # MacOS
+		iconv -f "$fchar" -t "$charmap//TRANSLIT" - </dev/null 2>/dev/null && trans=(-t "$charmap//TRANSLIT")
 		msg "append $sep$sep to filename to view the original $fchar encoded file"
 		cmd=(iconv "${rep[@]}" -f "$fchar" "${trans[@]}" "$2")
 		# loop protection, just in case
-		lclocale=
+		charmap=
 		return
 	fi
 	[[ "$3" == "$sep" ]] && return
@@ -368,8 +365,8 @@ get_unpack_cmd () {
 			{ has_cmd cpio && prog=cpio; } ||
 			{ has_cmd bsdtar && prog=bsdtar; } ;;
 		archive)
-			prog='ar'
-			has_cmd bsdtar && prog=bsdtar ;;
+			{ has_cmd ar && prog='ar'; } ||
+			{ has_cmd bsdtar && prog=bsdtar; } ;;
 		appimage|snap)
 			has_cmd unsquashfs && cmd=(isimage "$x" "$2" "$file2") ;;
 	esac
@@ -383,6 +380,11 @@ get_unpack_cmd () {
 				{ has_cmd 7za && prog=7za; } ;;
 		esac
 	fi
+	if [[ "$prog" = ar && "$2" = *@* ]]; then
+		t=$(nexttmp)
+		cat "$2" > "$t"
+		set "$2" "$t"
+	fi
 	[[ -n $prog ]] && cmd=(isarchive "$prog" "$2" "$file2")
 	if [[ -n ${cmd[*]} ]]; then
 		[[ -n "$file2" ]] && file2= && return
@@ -398,19 +400,14 @@ analyze_args () {
 	cmdtree=$(ps -T -oargs= 2>/dev/null)
 	while read -r line; do
 		arg1=${line%% *}; arg1=${arg1##*/}
-		case $arg1 in
-			man|git|perldoc)
-	# if lesspipe is called in pipes, return immediately for some use cases
-				exit 0 ;;
-			less)
-				lessarg=$line ;;
-		esac
+		[[ $arg1 == less ]] && lessarg=$line
 	done <<< "$cmdtree"
 	# return if we want to watch growing files
 	[[ $lessarg == *less\ *\ +F\ * || $lessarg == *less\ *\ : ]] && exit 0
 	# color is set when calling less with -r or -R or LESS contains that option
 	COLOR="--color=auto"
-	has_cmd tput && colors=$(tput colors) || colors=0
+	[[ $TERM == *256* ]] && colors=256 || colors=0
+	has_cmd tput && colors=$(tput colors)
 	if [[ $colors -ge 8 ]]; then
 		lessarg="$LESS $lessarg"
 		# shellcheck disable=SC2206
@@ -428,32 +425,47 @@ has_colorizer () {
 	[[ $COLOR == *always ]] || return
 	[[ $2 == plain || -z $2 ]] && return
 	prog=${LESSCOLORIZER%% *}
+	[[ $prog == vimcolor ]] && ! has_cmd vim && ! has_cmd nvim && prog=
 
-	for i in bat batcat pygmentize source-highlight vimcolor code2color ; do
+	for i in nvimpager bat batcat pygmentize source-highlight vim nvim code2color ; do
 		[[ -z $prog || $prog == "$i" ]] && has_cmd "$i" && prog=$i
 	done
+	[[ $prog == "*vim" ]] && prog=vimcolor
 	[[ "$2" =~ ^[0-9]*$ || -z "$2" ]] || lang=$2
 	# prefer an explicitly requested language
 	[[ -n $3 ]] && lang=$3 || lang=$2
 	case $prog in
 		bat|batcat)
+			batconfig=$($prog --config-file)
 			[[ -n $lang ]] && $prog --list-languages|sed 's/.*:/,/;s/$/,/'|grep -i ",$lang," > /dev/null && opt=(-l "$lang")
-			[[ -n $LESSCOLORIZER && $LESSCOLORIZER = *\ *--style=* ]] && style="${LESSCOLORIZER/* --style=/}"
+			opt2=${LESSCOLORIZER##*--}
+			[[ $opt2 == style=* ]] && style=${opt2##*=}
+			[[ $opt2 == theme=* ]] && theme=${opt2##*=}
+			opt2=$(echo "$LESSCOLORIZER"|tr -s ' ')
+			opt2=${opt2%[ ]--*}
+			opt2=${opt2##*--}
+			[[ $opt2 == style=* ]] && style=${opt2##*=}
+			[[ $opt2 == theme=* ]] && theme=${opt2##*=}
+			[[ -n $theme ]] && theme=$(echo "${theme##*=}"|tr -d '/"\047\134/')
 			[[ -z $style ]] && style=$BAT_STYLE
-			[[ -z $style ]] && style=plain
-			[[ -n $LESSCOLORIZER && $LESSCOLORIZER = *\ *--theme=* ]] && theme="${LESSCOLORIZER/* --theme=/}"
 			[[ -z $theme ]] && theme=$BAT_THEME
-			[[ -z $theme ]] && theme=ansi
-			if [[ -r "$HOME/.config/bat/config" ]]; then
-				grep -q -e '^--style' "$HOME/.config/bat/config" || opt+=(--style="${style%% *}")
-				grep -q -e '^--theme' "$HOME/.config/bat/config" || opt+=(--theme="${theme%% *}")
+			if [[ -r "$batconfig" ]]; then
+				if [[ -z $style ]]; then
+					grep -q -e '^--style' "$batconfig" || style=plain
+				fi
+				if [[ -z $theme ]]; then
+					grep -q -e '^--theme' "$batconfig" || theme=ansi
+				fi
 			else
-				opt+=(--style="${style%% *}" --theme="${theme%% *}")
+				[[ -z $style ]] && style=plain
+				[[ -z $theme ]] && theme=ansi
 			fi
+			style="${style%% *}" theme="${theme%%[|&;<>]*}"
+			opt+=(${style:+--style="$style"} ${theme:+--theme="$theme"})
 			opt+=("$COLOR" --paging=never "$1") ;;
 		pygmentize)
 			pygmentize -l "$lang" /dev/null &>/dev/null && opt=(-l "$lang") || opt=(-g)
-			[[ -n $LESSCOLORIZER && $LESSCOLORIZER = *-O\ *style=* ]] && style="${LESSCOLORIZER/*style=/}"
+			[[ -n $LESSCOLORIZER && $LESSCOLORIZER = *-[OP]\ *style=* ]] && style="${LESSCOLORIZER/*style=/}"
 			[[ -n $style ]] && opt+=(-O style="${style%% *}")
 			[[ $colors -ge 256 ]] && opt+=(-f terminal256)
 			[[ "$1" == - ]] || opt+=("$1") ;;
@@ -466,6 +478,10 @@ has_colorizer () {
 		code2color|vimcolor)
 			opt=("$1")
 			[[ -n "$3" ]] && opt=(-l "$3" "$1") ;;
+		nvimpager)
+			opt=(-c "$1")
+			[[ -n "$3" ]] && ft=${3##*/} && ft=${ft##*.} &&
+				opt=(-c "$1" --cmd "set filetype=$ft") ;;
 		*)
 			return ;;
 	esac
@@ -507,12 +523,12 @@ isfinal () {
 			{ has_cmd pdftohtml && has_htmlprog && cmd=(istemp ispdf "$1"); } ||
 			{ has_cmd pdfinfo && cmd=(istemp pdfinfo "$1"); } ;;
 		postscript)
-			has_cmd ps2ascii && nodash ps2ascii "$1" ;;
+			has_cmd ps2ascii && nodash ps2ascii "$1" 2>/dev/null ;;
 		java-applet)
 			# filename needs to end in .class
 			has_cmd procyon && t=$t.class && cat "$1" > "$t" && cmd=(procyon "$t") ;;
 		markdown)
-			[[ $COLOR = *always ]] && mdopt=() || mdopt=(-c)
+			[[ $COLOR = *always ]] && mdopt=(--ansi ) || mdopt=(-c)
 			{ has_cmd mdcat && cmd=(mdcat "${mdopt[@]}" "$1"); } ||
 			{ has_cmd pandoc && cmd=(pandoc -t plain "$1"); } ;;
 		docx)
@@ -521,10 +537,10 @@ isfinal () {
 			{ has_cmd libreoffice && cmd=(isoffice2 "$1"); } ;;
 		pptx)
 			{ has_cmd pptx2md && t2=$(nexttmp) &&
-				{ has_cmd mdcat && istemp "pptx2md --disable-image --disable-wmf \
+				{ { has_cmd mdcat && istemp "pptx2md --disable-image --disable-wmf \
 					-o $t2" "$1" && cmd=(mdcat "$t2"); } ||
 				{ has_cmd pandoc && istemp "pptx2md --disable-image --disable-wmf \
-					-o $t2" "$1" && cmd=(pandoc -f markdown -t plain "$t2"); }; } ||
+					-o $t2" "$1" && cmd=(pandoc -f markdown -t plain "$t2"); } }; } ||
 			{ can_do_office && cmd=(isoffice "$1" ppt); } ;;
 		xlsx|ods)
 			{ has_cmd xlscat && cmd=(istemp "xlscat -L -R all" "$1"); } ||
@@ -554,20 +570,20 @@ isfinal () {
 			declare macro=andoc
 			[[ "$fext" == me ]] && macro=e
 			[[ "$fext" == ms ]] && macro=s
-			{ has_cmd groff && cmd=(groff -s -p -t -e -Tutf8 -m "$macro" "$1"); } ||
 			{ has_cmd mandoc && cmd=(nodash mandoc "$1"); } ||
-			{ has_cmd man && cmd=(nodash man "$1"); } ;;
+			{ has_cmd man && cmd=(man -l "$1"); } ||
+			{ [[ $COLOR == *always ]] && has_cmd groff && cmd=(groff -s -p -t -e -Tutf8 -m "$macro" "$1"); } ;;
 		rtf)
 			{ has_cmd unrtf && cmd=(istemp "unrtf --text" "$1"); } ||
 			{ has_cmd libreoffice && cmd=(isoffice2 "$1"); } ;;
 		dvi)
 			has_cmd dvi2tty && cmd=(istemp "dvi2tty -q" "$1") ;;
 		sharedlib)
-			cmd=(istemp nm "$1") ;;
+			has_cmd nm && cmd=(istemp nm "$1") ;;
 		pod)
 			[[ -z $file2 ]] &&
 			{ { has_cmd pod2text && cmd=(pod2text "$1"); } ||
-			{ has_cmd perldoc && cmd=(istemp perldoc "$1"); }; } ;;
+			{ has_cmd perldoc && cmd=(istemp "perldoc -T" "$1"); }; } ;;
 		hdf|hdf5)
 			{ has_cmd h5dump && cmd=(istemp h5dump "$1"); } ||
 			{ has_cmd ncdump && cmd=(istemp ncdump "$1"); } ;;
@@ -576,19 +592,21 @@ isfinal () {
 		djvu)
 			has_cmd djvutxt && cmd=(djvutxt "$1") ;;
 		x509|crl)
-			has_cmd openssl && cmd=(istemp "openssl $x -hash -text -noout -in" "$1") ;;
+			has_cmd openssl && cmd=(openssl x509 -text -noout "$1") ;;
 		csr)
-			has_cmd openssl && cmd=(istemp "openssl req -text -noout -in" "$1") ;;
+			has_cmd openssl && cmd=(openssl req -text -noout -in "$1") ;;
 		pgp)
 			has_cmd gpg && cmd=(gpg --decrypt --quiet --no-tty --batch --yes "$1") ;;
-		plist)
+		bplist|plist)
 			{ has_cmd plistutil && cmd=(istemp "plistutil -i" "$1"); } ||
 			{ has_cmd plutil && cmd=(istemp "plutil -p" "$1"); } ;;
 		mp3)
-			has_cmd id3v2 && cmd=(istemp "id3v2 --list" "$1") ;;
+			{ has_cmd ffprobe && cmd=(ffprobe -hide_banner -- "$1"); } ||
+			{ has_cmd eyeD3 && cmd=(istemp "eyeD3" "$1"); } ||
+			{ has_cmd id3v2 && cmd=(istemp "id3v2 --list" "$1"); } ;;
 		log)
-			has_cmd ccze && [[ $COLOR = *always ]] && ccze -A < "$1"
-			return ;;
+			has_cmd ccze && [[ $COLOR = *always ]] && cmd=(istemp "ccze -A" "$1") ;;
+			#return ;;
 		csv)
 			msg "type -S<ENTER> for better display of very wide tables"
 			{ has_cmd csvtable && csvtable -h >/dev/null 2>&1 && cmd=(csvtable "$1"); } ||
@@ -606,6 +624,7 @@ isfinal () {
 	if [[ -z ${cmd[*]} ]]; then
 		fext=$(fileext "$1")
 		if [[ $fcat == audio || $fcat == video || $fcat == image ]]; then
+			{ has_cmd ffprobe && [[ $fcat != image ]] && cmd=(ffprobe -hide_banner -- "$1"); } ||
 			{ [[ "$1" != '-' ]] && has_cmd mediainfo && cmd=(mediainfo --Full "$1"); } ||
 			{ has_cmd exiftool && cmd=(exiftool "$1"); } ||
 			{ has_cmd identify && [[ $fcat == image ]] && cmd=(identify -verbose "$1"); }
@@ -625,11 +644,8 @@ isfinal () {
 	if [[ -n ${cmd[*]} ]]; then
 		# TAU: When cmd starts with environment variable settings, bash will refuse to execute it via : "${cmd[@]}"
 		# The remedy is simple : Just run it through the "env" command in that case.
-		if [[ "$cmd" =~ '=' ]]; then
-			cmd=(env "${cmd[@]}")
-		fi
-		#[[ -n ${colorizer[*]} ]] && "${cmd[@]}" | "${colorizer[@]}" && return
-		"${cmd[@]}"
+		[[ "$cmd" =~ '=' ]] && cmd=(env "${cmd[@]}")
+		"${cmd[@]}" 2>&1
 	else
 		[[ -n ${colorizer[*]} && $fcat != binary ]] && "${colorizer[@]}" && return
 		# if fileext set, we need to filter to get rid of .fileext
@@ -644,10 +660,10 @@ isarchive () {
 		case $prog in
 			tar|bsdtar)
 				[[ "$2" =~ ^[a-z_-]*:.* ]] && echo "$2: remote operation tar host:file not allowed" && return
-				if [[ "$3" =~ --* ]]; then
-					$prog Oxf "$2" "--" "$3" 2>/dev/null
+				if [[ "$3" =~ .*/$ ]]; then
+					$prog Otvf "$2" -- "$3"
 				else
-					$prog Oxf "$2" "$3" 2>/dev/null
+					$prog Oxf "$2" -- "$3" 2>/dev/null
 				fi
 				;;
 			rar|unrar)
@@ -661,10 +677,14 @@ isarchive () {
 			isoinfo)
 				istemp "isoinfo -i" "$2" "-x$3" ;;
 			cpio)
-				if [[ "$2" == - ]]; then
-					cpio -i --quiet --to-stdout "$3"
+				if [[ $(cpio --version) = *GNU* ]]; then
+					if [[ "$2" == - ]]; then
+						cpio -i --quiet --to-stdout "$3"
+					else
+						cpio -i --quiet --to-stdout --file "$2" "$3"
+					fi
 				else
-					cpio -i --quiet --to-stdout --file "$2" "$3"
+					msg "cpio: this version cannot extract files to a pipe"
 				fi ;;
 			7zz|7za|7zr)
 				istemp "$prog e -so" "$2" "$3"
@@ -689,11 +709,7 @@ isarchive () {
 				separatorline
 				isoinfo -fR"$joliet" -i "$t" ;;
 			cpio)
-				if [[ "$2" == - ]]; then
-					cpio -tv --quiet
-				else
-					cpio -tv --quiet --file "$2"
-				fi ;;
+				cpio -tv --quiet < "$2" ;;
 			7zz|7za|7zr)
 				istemp "$prog l" "$2"
 		esac
@@ -714,13 +730,10 @@ isimage () {
 		offset="-o $("$2" --appimage-offset)"
 	fi
 	if [[ -z "$3" ]]; then
-		if [[ "$1" == snap ]]; then
-			has_cmd snap && snap info "$2"
-			separatorline
-		fi
+		[[ "$1" == snap ]] && has_cmd snap && snap info "$2" && separatorline
 		istemp "unsquashfs -d . -llc $offset" "$2"
 	else
-		istemp "unsquashfs -cat $offset"  "$2" "$3"
+		istemp "unsquashfs -cat $offset" "$2" "$3"
 	fi
 }
 
@@ -760,6 +773,11 @@ isdeb () {
 			bsdtar xOf "$1" "$data" | bsdtar xOf - "$2"
 		fi
 	else
+		if [[ "$1" = *@* ]]; then
+			t=$(nexttmp)
+			cat "$1" > "$t"
+			set "$1" "$t"
+		fi
 		data=$(ar t "$1"|grep data)
 		ft=$(ar p "$1" "$data" | filetype -)
 		get_unpack_cmd "$ft" -
@@ -828,13 +846,15 @@ handle_w3m () {
 
 ishtml () {
 	[[ $1 == - ]] && arg1=-stdin || arg1="$1"
+	htmlopt=--unicode-snob
+	has_cmd html2text && html2text -utf8 </dev/null 2>/dev/null && htmlopt=-utf8
 	# 3 lines following can easily be reshuffled according to the preferred tool
 	has_cmd elinks && nodash "elinks -dump -force-html" "$1" && return ||
 	has_cmd w3m && handle_w3m "$1" && return ||
 	has_cmd lynx && lynx -force_html -dump "$arg1" && return ||
-	# different versions of html2text existing, therefore no encoding handling
+	# different versions of html2text existingi, force unicode
 	[[ "$1" == https://* ]] && return ||
-	has_cmd html2text && nodash html2text "$1"
+	has_cmd html2text && nodash html2text "$htmlopt" "$1"
 }
 
 # the main program
@@ -842,8 +862,9 @@ set +o noclobber
 setopt sh_word_split 2>/dev/null
 PATH=$PATH:${0%%/lesspipe.sh}
 # the current locale in lowercase (or generic utf-8)
-locale=$(locale|grep LC_CTYPE|tr -d '"') || locale=utf-8
-lclocale=$(echo "${locale##*.}"|tr '[:upper:]' '[:lower:]')
+charmap=$(locale -k charmap 2>/dev/null|tr '[:upper:]' '[:lower:]') || charmap="charmap=utf-8"
+eval "$charmap"
+has_cmd locale || charmap=
 
 sep=:					# file name separator
 altsep='='				# alternate separator character
@@ -879,9 +900,8 @@ if [[ -z "$1" && "$0" == */lesspipe.sh ]]; then
 		echo "export LESSOPEN"
 	fi
 else
-	if [ -x "${HOME}/.lessfilter" ]; then
-		"${HOME}/.lessfilter" "$1" && exit 0
-	elif has_cmd lessfilter; then
+	[[ -x "${HOME}/.lessfilter" ]] && "${HOME}/.lessfilter" "$1" && exit 0
+	if has_cmd lessfilter; then
 		lessfilter "$1" && exit 0
 	fi
 	if [[ -z "$1" ]]; then
